### [natch](#)

Pattern matching library.

[![PyPI Version](https://img.shields.io/pypi/v/natch?logo=pypi)](https://pypi.org/project/natch/)
[![Docs](https://img.shields.io/badge/API-docs-orange.svg?style=flat-square&logo=python)](https://readthedocs.org/projects/natch/)
[![Status](https://img.shields.io/circleci/build/github/ertgl/natch?style=flat-square&logo=circleci)](https://circleci.com/gh/ertgl/natch)
[![GitHub](https://img.shields.io/badge/vcs-GitHub-blue.svg?style=flat-square&logo=github)](https://github.com/ertgl/natch)
[![MIT License](https://img.shields.io/pypi/l/natch?color=blue&style=flat-square)](LICENSE.txt)

---

**`Installation`**

```bash
pip install natch
```
